#!/bin/sh
#
# InnoTek VirtualBox
#
# Copyright (C) 2006 InnoTek Systemberatung GmbH
#
# This file is part of VirtualBox Open Source Edition (OSE), as
# available from http://www.virtualbox.org. This file is free software;
# you can redistribute it and/or modify it under the terms of the GNU
# General Public License as published by the Free Software Foundation,
# in version 2 as it comes in the "COPYING" file of the VirtualBox OSE
# distribution. VirtualBox OSE is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY of any kind.
#
# If you received this file as part of a commercial VirtualBox
# distribution, then only the terms of your commercial VirtualBox
# license agreement apply instead of the previous paragraph.

CONFIG="/etc/vbox/vbox.cfg"
if [ "$VBOX_USER_HOME" = "" ]; then
    if [ ! -d "$HOME/.VirtualBox" ]; then
        mkdir -p "$HOME/.VirtualBox"
    fi
    LOG="$HOME/.VirtualBox/VBoxSVC.log"
else
    if [ ! -d "$VBOX_USER_HOME" ]; then
        mkdir -p "$VBOX_USER_HOME"
    fi
    LOG="$VBOX_USER_HOME/VBoxSVC.log"
fi


if [ ! -r "$CONFIG" ]; then
    echo "Could not find VirtualBox installation. Please reinstall."
    exit 1
fi

if [ "$1" = "shutdown" ]; then
    SHUTDOWN="true"
elif [ ! -w /dev/vboxdrv ]; then
    if [ "`id | grep vboxusers`" = "" ]; then
        echo 'You are not a member of the "vboxusers" group.  Please add yourself to this'
        echo 'group before starting VirtualBox.'
    else
        echo '/dev/vboxdrv not writable for some reason. If you recently added the current'
        echo 'user to the vboxusers group then you have to logout and re-login to take the'
        echo 'change effect.'
    fi
    exit 1
fi

. "$CONFIG_DIR/$CONFIG"

# Note: This script must not fail if the module was not successfully installed
#       because the user might not want to run a VM but only change VM params!
if [ -f /etc/vbox/module_not_compiled ]; then
    cat << EOF
WARNING: The compilation of the vboxdrv.ko kernel module failed during the
         installation for some reason. Starting a VM will not be possible.
         Please consult the User Manual for build instructions.
EOF
fi

export LD_LIBRARY_PATH="$INSTALL_DIR"

SERVER_PID=`ps -U \`whoami\` | grep VBoxSVC | awk '{ print $1 }'`
if [ "$SHUTDOWN" = "" ] && [ "$SERVER_PID" = "" ]; then
    rm -rf /tmp/.vbox-`whoami`-ipc > /dev/null 2>&1
    [ -f "$LOG.1" ] && mv "$LOG.1" "$LOG.2"
    [ -f "$LOG.0" ] && mv "$LOG.0" "$LOG.1"
    [ -f "$LOG" ] && mv "$LOG" "$LOG.0"
    "$INSTALL_DIR/VBoxSVC" --daemonize > "$LOG" 2>&1
fi

if [ "$SHUTDOWN" = "true" ]; then
    if [ "$SERVER_PID" != "" ]; then
        kill -TERM $SERVER_PID
        sleep 2
    fi
    exit 0
fi

APP=`which $0`
APP=${APP##/*/}
case "$APP" in
  VirtualBox)
    exec "$INSTALL_DIR/VirtualBox" "$@"
  ;;
  VBoxManage)
    exec "$INSTALL_DIR/VBoxManage" "$@"
  ;;
  VBoxSDL)
    exec "$INSTALL_DIR/VBoxSDL" "$@"
  ;;
  VBoxVRDP)
    exec "$INSTALL_DIR/VBoxVRDP" "$@"
  ;;
  *)
    echo "Unknown application - $APP"
  ;;
esac
